import express from 'express';
import cors from 'cors';
import { animals, requests } from './resources';

const api = express();

api.use(cors());

api.use(express.json());
api.use(express.urlencoded({ extended: true }));

api.use(express.static('public'));

/**
 * Send greetings to API Client
 */
api.get('/', (req, res) => res.send({
  status: 'success',
  data: {},
  message: 'Welcome to our API'
}));

/**
 * Resource animals
 */
api.get('/animals', animals.list);
api.post('/animals', animals.store);
api.get('/animals/:id', animals.get);

/**
 * Resource requests
 */
api.get('/requests', requests.list);
api.get('/requests/:id', requests.show);
api.patch('/requests/:id', requests.partialUpdate);
api.put('/requests/:id', requests.update);
api.post('/requests', requests.store);
api.delete('/requests/:id', requests.destroy);

/**
 * Start listening on connections
 */
api.listen(process.env.PORT, () => console.log(`Example app listening on port ${process.env.PORT}`));
